#ifndef LOG4QT_CLASSLOGGER_H
#define LOG4QT_CLASSLOGGER_H

#include <QtCore/QObject>
#include <QtCore/QAtomicPointer>

namespace Log4Qt
{
	class Logger;

	/*!
	 * \brief The class ClassLogger provides logging for a QObject derived
	 *        class.
	 *
	 * The class ClassLogger provides a logger for a specified QObject derived
	 * object. It is used by \ref LOG4QT_DECLARE_QCLASS_LOGGER to implement the
	 * member functions provided by the macro.
	 *
	 * \note All the functions declared in this class are thread-safe.
	 *
	 * \sa LOG4QT_DECLARE_QCLASS_LOGGER
	 */
	class ClassLogger
	{
	public:
	    /*!
	     * Creates a ClassLogger object.
	     */
	    ClassLogger();
	    // ~ClassLogger(); // Use compiler default
	    // ClassLogger(const ClassLogger &rOther); // Use compiler default
	    // ClassLogger &operator=(const ClassLogger &rOther); // Use compiler default

	    /*!
	     * Returns a pointer to a Logger named after the class of the object
	     * \a pObject.
	     *
	     * On the first invocation the Logger is requested by a call to
	     * LogManager::logger(const char *pName). The pointer is stored to be
	     * returned on subsequent invocations.
	     *
	     * \sa LogManager::logger(const char *pName)
	     */
	    Logger *logger(const QObject *pObject);

	private:
	    mutable QAtomicPointer<Logger> mpLogger;
	};
} // namespace Log4Qt


// Q_DECLARE_TYPEinfo(Log4Qt::ClassLogger, Q_COMPLEX_TYPE); // Use default


#endif // LOG4QT_CLASSLOGGER_H
