#ifndef LOG4QT_HIERARCHY_H
#define LOG4QT_HIERARCHY_H

#include "loggerrepository.h"

#include <QtCore/QHash>
#include <QtCore/QReadWriteLock>

namespace Log4Qt
{
	/*!
	 * \brief The class Hierarchy implements a logger repository.
	 * 
	 * \note All the functions declared in this class are thread-safe.
	 */
	class Hierarchy : public LoggerRepository
	{
	public:
	    Hierarchy();
	    // Hierarchy(const Hierarchy &rOther); // Use compiler default
	    virtual ~Hierarchy();
	    // Hierarchy &operator=(const Hierarchy &rOther); // Use compiler default
	        
	public:
	    virtual bool exists(const QString &rName) const;
        virtual Logger *logger(const QString &rName, const QString &alias = QString());
	    virtual QList<Logger *> loggers() const;
	    virtual Logger *rootLogger() const;
	    virtual Level threshold() const;
	    virtual void setThreshold(Level level);
	    virtual void setThreshold(const QString &rThreshold);
	    virtual bool isDisabled(Level level);
	    virtual void resetConfiguration();
	    virtual void shutdown();
	
	protected:
#ifndef QT_NO_DEBUG_STREAM
	    /*!
	     * Writes all object member variables to the given debug stream \a rDebug and
	     * returns the stream.
	     *
	     * <tt>
	     * %Hierarchy(loggers:6 threshold:"ALL" root-level:"DEBUG" root-appenders:0)
	     * </tt>
	     * \sa QDebug, operator<<(QDebug debug, const LoggerRepository &rLoggerRepository)
	     */
	    virtual QDebug debug(QDebug &rdebug) const;
#endif
	    
	private:
        Logger *createLogger(const QString &rName, const QString &alias = QString());
	    void resetLogger(Logger *pLogger, Level level) const;
	
	private:
	    mutable QReadWriteLock mObjectGuard;
	    QHash<QString, Logger*> mLoggers;
	    volatile bool mHandleQtMessages;
	    Level mThreshold;
	    Logger *mpRootLogger;
	};
	
} // namespace Log4Qt

// Q_DECLARE_TYPEINFO(Log4Qt::Hierarchy, Q_COMPLEX_TYPE); // Use default

#endif // LOG4QT_HIERARCHY_H
