#ifndef LOG4QT_LAYOUT_H
#define LOG4QT_LAYOUT_H

#include "helpers/logobject.h"

#include "helpers/logobjectptr.h"
#include "log4qt.h"

namespace Log4Qt
{    
	class LoggingEvent;
	
	/*!
	 * \brief The class Layout is the base class for all layouts.
	 * 
	 * \note The ownership and lifetime of objects of this class are managed. See
	 *       \ref Ownership "Object ownership" for more details.
	 */
	class Layout : public LogObject
	{
	    Q_OBJECT
	
	    /*!
	     * The property holds the content type of the layout.
	     *
	     * \sa contentType()
	     */
	    Q_PROPERTY(QString footercontentType READ contentType)
	    /*!
	     * The property holds the footer used by the layout.
	     *
	     * \sa footer(), setFooter()
	     */
	    Q_PROPERTY(QString footer READ footer WRITE setFooter)
	    /*!
	     * The property holds the header used by the layout.
	     *
	     * \sa header(), setHeader()
	     */
	    Q_PROPERTY(QString header READ header WRITE setHeader)
	    
	public:
	    Layout(QObject *pParent = 0);
	    virtual ~Layout();

	private:
	    Layout(const Layout &rOther); // Not implemented
	    Layout &operator=(const Layout &rOther); // Not implemented
	        
	public:
	    virtual QString contentType() const;
	    QString footer() const;
	    QString header() const;
	    // JAVA: virtual bool ignoresThrowable() const;
	    QString name() const;
	    void setFooter(const QString &rFooter);
	    void setHeader(const QString &rHeader);
	    void setName(const QString &rName);
	    // JAVA: void setIgnoresThrowable(bool) const;
	
	    virtual void activateOptions();
	    virtual QString format(const LoggingEvent &rEvent) = 0;
	    
		/*! 
		 * Returns the end of line seperator for the operating system.
		 * 
		 * Windows: \\r\\n
		 * Mac: \\r
		 * UNIX: \\n
		 */
		static QString endOfLine();
	    
	    // Member variables
	private:
	    QString mFooter;
	    QString mHeader;
	};
	
} // namespace Log4Qt

// Q_DECLARE_TYPEINFO(Log4Qt::Layout, Q_COMPLEX_TYPE); // Use default
Q_DECLARE_TYPEINFO(Log4Qt::LogObjectPtr<Log4Qt::Layout>, Q_MOVABLE_TYPE);

#endif // LOG4QT_LAYOUT_H
