#ifndef LOG4QT_MDC_H
#define LOG4QT_MDC_H

#include <QtCore/QString>
#include <QtCore/QHash>
#include <QtCore/QThreadStorage>
#include "log4qt.h"

namespace Log4Qt 
{
    /*!
	 * \brief The class MDC implements a mapped diagnostic context.
	 * 
	 * \note All the functions declared in this class are thread-safe.
	 */
	class MDC
	{
	private:
	    MDC();
	    MDC(const MDC &rOther); // Not implemented
	    // virtual ~MDC(); // Use compiler default
	    MDC &operator=(const MDC &rOther); // Not implemented
	        
	public:
	    static QString get(const QString &rKey);
	    static QHash<QString, QString> context();

        /*!
         * Returns the MDC instance.
         */
        static MDC *instance();
        
	    static void put(const QString &rKey, const QString &rValue);
	    static void remove(const QString &rKey);
	
    private:
	    static QHash<QString, QString> *localData();
	    
	private:
	    QThreadStorage< QHash<QString, QString> * > mHash;
	};
	
#ifndef QT_NO_DEBUG_STREAM
	/*!
	 * \relates MDC
	 * 
	 * Writes all object member variables to the given debug stream \a rDebug
	 * and returns the stream.
	 *
	 * <tt>
	 * %MDC(thread:"main" context:QHash(("login", "Peter")("database", "UAT")) ) 
	 * </tt>
	 * \sa QDebug
	 */
    QDebug operator<<(QDebug debug, const MDC &rMDC);
#endif // QT_NO_DEBUG_STREAM
		
} // namespace Log4Qt

// Q_DECLARE_TYPEINFO(Log4Qt::MDC, Q_COMPLEX_TYPE); // Use default

#endif // LOG4QT_MDC_H
