#ifndef LOG4QT_FILTER_H
#define LOG4QT_FILTER_H

#include "helpers/logobject.h"

#include "helpers/logobjectptr.h"
#include "log4qt.h"

namespace Log4Qt
{
	class LoggingEvent;
	
	/*!
	 * \brief The class Filter is the base class for all filters.
	 * 
	 * \note The ownership and lifetime of objects of this class are managed. 
	 *       See \ref Ownership "Object ownership" for more details.
	 */
	class Filter : public LogObject
	{
		Q_OBJECT
	
	    /*!
	     * The property holds the next filter of this filter.
	     *
	     * The default is 0 for no next filter.
	     * 
	     * \sa next(), setNext()
	     */
	    Q_PROPERTY(Filter* next READ next WRITE setNext)
		
	public:
	    enum Decision
	    {
	    	ACCEPT, 
	    	DENY,
	    	NEUTRAL  
	    };
        Q_ENUMS(Decision)
	    
	public:
	    Filter(QObject *pObject = 0);
	    // Filter(const Filter &rOther); // Use compiler default
	    virtual ~Filter();
	    // Filter &operator=(const Filter &rOther); // Use compiler default
	    
	    Filter* next() const;
	    void setNext(Filter *pFilter);
	
	    virtual void activateOptions();
	    virtual Decision decide(const LoggingEvent &rEvent) const = 0;
	
	private:
	    LogObjectPtr<Filter> mpNext;
	};
	
} // namespace Log4Qt

// Q_DECLARE_TYPEINFO(Log4Qt::Filter, Q_COMPLEX_TYPE); // Use default
Q_DECLARE_TYPEINFO(Log4Qt::LogObjectPtr<Log4Qt::Filter>, Q_MOVABLE_TYPE);

#endif // LOG4QT_FILTER_H
