#ifndef LOG4QT_DENYALLFILTER_H
#define LOG4QT_DENYALLFILTER_H

#include "spi/filter.h"

namespace Log4Qt
{
	/*!
	 * \brief The class DenyAllFilter drops all logging events
	 * 
	 * \note The ownership and lifetime of objects of this class are managed. 
	 *       See \ref Ownership "Object ownership" for more details.
	 */
	class DenyAllFilter : public Filter
	{
		Q_OBJECT
		
	public:
	    DenyAllFilter(QObject *pParent = 0);
	    // DenyAllFilter(const DenyAllFilter &rOther); // Use compiler default
	    // virtual ~DenyAllFilter(); // Use compiler default
	    // DenyAllFilter &operator=(const DenyAllFilter &rOther); // Use compiler default
	
	    virtual Decision decide(const LoggingEvent &rEvent) const;
	
	protected:
#ifndef QT_NO_DEBUG_STREAM
	    /*!
	     * Writes all object member variables to the given debug stream \a rDebug 
	     * and returns the stream.
	     *
	     * <tt>
	     * %DenyAllFilter(next:QObject(0x0) referencecount:1 ) 
	     * </tt>
	     * \sa QDebug, operator<<(QDebug debug, const LogObject &rLogObject)
	     */
		virtual QDebug debug(QDebug &rDebug) const;
#endif // QT_NO_DEBUG_STREAM
	};
	
} // namespace Log4Qt

// Q_DECLARE_TYPEINFO(Log4Qt::DenyAllFilter, Q_MOVABLE_TYPE); // Use default

#endif // LOG4QT_DENYALLFILTER_H
