#ifndef LOG4QT_NULLAPPENDER_H
#define LOG4QT_NULLAPPENDER_H

#include "appenderskeleton.h"

namespace Log4Qt
{
    /*!
     * \brief The class NullAppender ignores all requests to append.
     *
     * \note All the functions declared in this class are thread-safe.
     *
     * \note The ownership and lifetime of objects of this class are managed. See
     *       \ref Ownership "Object ownership" for more details.
     */
    class NullAppender : public AppenderSkeleton
    {
        Q_OBJECT

    public:
        NullAppender(QObject *pParent = 0);
        virtual ~NullAppender();
    private:
        NullAppender(const NullAppender &rOther); // Not implemented
        NullAppender &operator=(const NullAppender &rOther); // Not implemented

    public:
        virtual bool requiresLayout() const;

    protected:
        virtual void append(const LoggingEvent &rEvent);

    #ifndef QT_NO_DEBUG_STREAM
        /*!
         * Writes all object member variables to the given debug stream \a rDebug and
         * returns the stream.
         *
         * <tt>
         * %NullAppender()
         * </tt>
         * \sa QDebug, operator<<(QDebug debug, const LogObject &rLogObject)
         */
        virtual QDebug debug(QDebug &rDebug) const;
    #endif // QT_NO_DEBUG_STREAM
    };

} // namespace Log4Qt

// Q_DECLARE_TYPEINFO(Log4Qt::NullAppender, Q_COMPLEX_TYPE); // Use default

#endif // LOG4QT_NULLAPPENDER_H
